@@ -105,29 +105,25 @@ get_consumer_secret (GoaOAuthProvider *oauth_provider)
 static const gchar *
 get_request_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://www.flickr.com/services/oauth/request_token";
+  return "https://m.flickr.com/services/oauth/request_token";
 }
 
 static const gchar *
 get_authorization_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://www.flickr.com/services/oauth/authorize";
+  return "https://m.flickr.com/services/oauth/authorize";
 }
 
 static const gchar *
 get_token_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://www.flickr.com/services/oauth/access_token";
+  return "https://m.flickr.com/services/oauth/access_token";
 }
 
 static const gchar *
 get_callback_uri (GoaOAuthProvider *oauth_provider)
 {
-  /* Should match the URI specified in the Flickr App
-   * Garden in order to detect when the user denied access via
-   * the OAuth1 web page.
-   */
-  return "https://www.gnome.org/";
+  return "https://www.gnome.org/goa-1.0/oauth";
 }
 
 static const gchar *
@@ -146,23 +142,14 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
                    GCancellable      *cancellable,
                    GError           **error)
 {
-  GError *identity_error;
-  RestProxy *proxy;
-  RestProxyCall *call;
-  JsonParser *parser;
+  GError *identity_error = NULL;
+  RestProxy *proxy = NULL;
+  RestProxyCall *call = NULL;
+  JsonParser *parser = NULL;
   JsonObject *json_object;
-  gchar *ret;
-  gchar *id;
-  gchar *presentation_identity;
-
-  ret = NULL;
-
-  identity_error = NULL;
-  proxy = NULL;
-  call = NULL;
-  parser = NULL;
-  id = NULL;
-  presentation_identity = NULL;
+  gchar *ret = NULL;
+  gchar *id = NULL;
+  gchar *presentation_identity = NULL;
 
   /* TODO: cancellable */
 
@@ -274,11 +261,8 @@ static gboolean
 is_deny_node (GoaOAuthProvider *oauth_provider, WebKitDOMNode *node)
 {
   WebKitDOMElement *element;
-  gboolean ret;
-  gchar *id;
-
-  id = NULL;
-  ret = FALSE;
+  gboolean ret = FALSE;
+  gchar *id = NULL;
 
   if (!WEBKIT_DOM_IS_HTML_ANCHOR_ELEMENT (node))
     goto out;
@@ -314,11 +298,9 @@ static gchar *
 parse_request_token_error (GoaOAuthProvider *oauth_provider, RestProxyCall *call)
 {
   const gchar *payload;
-  gchar *msg;
+  gchar *msg = NULL;
   guint status;
 
-  msg = NULL;
-
   payload = rest_proxy_call_get_payload (call);
   status = rest_proxy_call_get_status_code (call);
 
@@ -339,12 +321,9 @@ build_object (GoaProvider         *provider,
               gboolean             just_added,
               GError             **error)
 {
-  GoaAccount *account;
+  GoaAccount *account = NULL;
   gboolean photos_enabled;
-  gboolean ret;
-
-  account = NULL;
-  ret = FALSE;
+  gboolean ret = FALSE;
 
   /* Chain up */
   if (!GOA_PROVIDER_CLASS (goa_flickr_provider_parent_class)->build_object (provider,
