@@ -251,12 +251,11 @@ sign_in_identity_finish (GoaKerberosProvider  *self,
   GTask *task;
 
   g_return_val_if_fail (GOA_IS_KERBEROS_PROVIDER (self), NULL);
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
   g_return_val_if_fail (g_task_is_valid (result, self), NULL);
   task = G_TASK (result);
 
-  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
-
   return g_task_propagate_pointer (task, error);
 }
 
@@ -1511,7 +1510,7 @@ remove_account_finish (GoaProvider   *provider,
   g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
   task = G_TASK (res);
 
-  g_warn_if_fail (g_task_get_source_tag (task) == remove_account);
+  g_return_val_if_fail (g_task_get_source_tag (task) == remove_account, FALSE);
 
   return g_task_propagate_boolean (task, error);
 }
@@ -1570,7 +1569,7 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
 {
   GcrSecretExchange  *secret_exchange;
   char               *secret_key;
-  char               *return_key;
+  char               *return_key = NULL;
   char               *concealed_secret;
   char               *identity_object_path = NULL;
   gboolean            keys_exchanged;
@@ -1624,6 +1623,7 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
   g_mutex_unlock (&identity_manager_mutex);
 
  out:
+  g_free (return_key);
   g_object_unref (secret_exchange);
   return identity_object_path;
 }
