@@ -65,7 +65,7 @@ get_provider_type (GoaProvider *provider)
 static gchar *
 get_provider_name (GoaProvider *provider, GoaObject *object)
 {
-  return g_strdup(_("ownCloud"));
+  return g_strdup(_("Nextcloud"));
 }
 
 static GoaProviderGroup
